media_player

package
v0.0.0-...-506d839 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 24, 2024 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

const (
	MethodInit                  = "init"
	MethodSeeked                = "seeked"
	MethodMetadataUpdated       = "mu"
	MethodPlaybackStatusUpdated = "psu"
	MethodRList                 = "rlist"
	// "NameOwnerChanged" Signals
	MethodPlayerCreated = "cr"
	MethodPlayerUpdated = "up"
	MethodPlayerRemoved = "rm"
	// TODO: Switch this to "init" soon
	MethodRSetupMetadata = "rsetup_metadata"
)

-- MP:Linux Methods TODO: Move to ganymede.

const (
	DBusMPRISPath          = "/org/mpris/MediaPlayer2"
	SeekedMember           = "Seeked"
	PlayerSeekedMemberName = "org.mpris.MediaPlayer2.Player.Seeked"
)
const (
	MediaPlayerSubsystemName = "mp"
)

Variables

This section is empty.

Functions

func MPAutoPlatformMethod

func MPAutoPlatformMethod(method string) string

func MPMethod

func MPMethod(method string) string

Types

type LinuxMediaPlayerSubsystem

type LinuxMediaPlayerSubsystem struct {
	// contains filtered or unexported fields
}

func NewLinuxMediaPlayerSubsystem

func NewLinuxMediaPlayerSubsystem(bidirChan *comm.BiDirMessageChannel) *LinuxMediaPlayerSubsystem

func (*LinuxMediaPlayerSubsystem) Routine

func (lmp *LinuxMediaPlayerSubsystem) Routine()

Main Subsystem Routine + Communication Loop

This loop reads from command channel (from other modules) and communication channel (for communication with client).

func (*LinuxMediaPlayerSubsystem) Setup

func (lmp *LinuxMediaPlayerSubsystem) Setup() error

Main Setup Method

This sets up the media player subsystem for linux, which includes setting up DBus Session Connections for MPRIS and Adding Players for the first launch, and anything else related to the same.

func (*LinuxMediaPlayerSubsystem) Shutdown

func (lmp *LinuxMediaPlayerSubsystem) Shutdown()

type PlayerSelection

type PlayerSelection struct {
	PlayerName string
	// contains filtered or unexported fields
}

Jump to